window.Gleam.initSearch([{"doc":"zip_list","title":"zip_list","content":"# zip_list\n\n[![Package Version](https://img.shields.io/hexpm/v/zip_list)](https://hex.pm/packages/zip_list)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/zip_list/)\n\nA `ZipList` is a list-like data structure that maintains a selected element. It provides operations to navigate through the elements, as well as to insert or remove elements.\n\nIt is useful for various implementations, such as:\n\n- **Navigable Menus**: Create menus with options that users can navigate through.\n- **Image Carousels**: Implement carousels of images that users can scroll through.\n\n## Installation\n\n```sh\ngleam add zip_list\n```\n\n## Usage\n\n```gleam\nimport gleam/io\nimport zip_list\n\npub fn main() {\n    let animals =\n        zip_list.new([], &quot;Dog&quot;, [&quot;Cat&quot;, &quot;Bird&quot;, &quot;Fish&quot;])\n        |&gt; zip_list.next\n\n    io.println(&quot;You selected: &quot; &lt;&gt; zip_list.current(animals)) // =&gt; &quot;You selected: Cat&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/zip_list&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"zip_list","title":"ZipList","content":"pub opaque type ZipList(a)\n\n\nSynonyms:\nzip_list.ZipList\nzip_list ZipList","url":"zip_list.html#ZipList"},{"doc":"zip_list","title":"append_next","content":"pub fn append_next(\n  zip_list: ZipList(a),\n  next: List(a),\n) -&gt; ZipList(a)\n Append a list to the next elements of the ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n append_next(numbers, [6, 7]) == new([1, 2], 3, [4, 5, 6, 7])\n \nSynonyms:\nzip_list.append_next\nzip_list append_next","url":"zip_list.html#append_next"},{"doc":"zip_list","title":"append_previous","content":"pub fn append_previous(\n  zip_list: ZipList(a),\n  previous: List(a),\n) -&gt; ZipList(a)\n Append a list to the previous elements of the ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n append_previous(numbers, [-1, 0]) == new([1, 2, -1, 0], 3, [4, 5])\n \nSynonyms:\nzip_list.append_previous\nzip_list append_previous","url":"zip_list.html#append_previous"},{"doc":"zip_list","title":"backwards","content":"pub fn backwards(zip_list: ZipList(a), times: Int) -&gt; ZipList(a)\n Move the cursor N elements backwards\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n backwards(numbers, 2) == new([], 1, [2, 3, 4, 5])\n \n \n let numbers = new([1, 2], 3, [4, 5])\n backwards(numbers, 5) == new([], 1, [2, 3, 4, 5])\n \nSynonyms:\nzip_list.backwards\nzip_list backwards","url":"zip_list.html#backwards"},{"doc":"zip_list","title":"current","content":"pub fn current(zip_list: ZipList(a)) -&gt; a\n Get the current element of the ZipList\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; current\n // =&gt; 3\n \nSynonyms:\nzip_list.current\nzip_list current","url":"zip_list.html#current"},{"doc":"zip_list","title":"current_map","content":"pub fn current_map(\n  zip_list: ZipList(a),\n  f: fn(a, Bool) -&gt; a,\n) -&gt; ZipList(a)\n Map a function over the elements of the ZipList, passing a flag indicating if the element is the current element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n current_map(numbers, fn(x, is_current) {\n   case is_current {\n     True -&gt; x * 10\n     False -&gt; x * 2\n   }\n }) == new([2, 4], 30, [8, 10])\n \nSynonyms:\nzip_list.current_map\nzip_list current_map","url":"zip_list.html#current_map"},{"doc":"zip_list","title":"filter","content":"pub fn filter(\n  zip_list: ZipList(a),\n  f: fn(a) -&gt; Bool,\n) -&gt; Result(ZipList(a), Nil)\n Filter the elements of the ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n filter(numbers, int.is_even) == new([2], 4, [])\n \n \n let numbers = new([1, 2], 3, [4, 5])\n filter(numbers, int.is_odd) == new([1], 3, [5])\n \n \n let numbers = new([], 1, [])\n filter(numbers, int.is_even) == Error(Nil)\n \nSynonyms:\nzip_list.filter\nzip_list filter","url":"zip_list.html#filter"},{"doc":"zip_list","title":"first","content":"pub fn first(zip_list: ZipList(a)) -&gt; ZipList(a)\n Move the cursor to the first element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n first(numbers) == new([], 1, [2, 3, 4, 5])\n \n \n let numbers = new([], 1, [2, 3, 4, 5])\n first(numbers) == new([], 1, [2, 3, 4, 5])\n \nSynonyms:\nzip_list.first\nzip_list first","url":"zip_list.html#first"},{"doc":"zip_list","title":"forward","content":"pub fn forward(zip_list: ZipList(a), times: Int) -&gt; ZipList(a)\n Move the cursor N elements forward\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n forward(numbers, 2) == new([1, 2, 3, 4], 5, [])\n \n \n let numbers = new([1, 2], 3, [4, 5])\n forward(numbers, 5) == new([1, 2, 3, 4, 5], 6, [])\n \nSynonyms:\nzip_list.forward\nzip_list forward","url":"zip_list.html#forward"},{"doc":"zip_list","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Result(ZipList(a), Nil)\n Create a new ZipList from a list\n Returns `Error(Nil)` if the list is empty\n\n ## Examples\n \n from_list([1, 2, 3, 4, 5]) == Ok(new([], 1, [2, 3, 4, 5]))\n from_list([]) == Error(Nil)\n \nSynonyms:\nzip_list.from_list\nzip_list from_list","url":"zip_list.html#from_list"},{"doc":"zip_list","title":"from_list_by","content":"pub fn from_list_by(\n  list: List(a),\n  predicate: fn(a) -&gt; Bool,\n) -&gt; Result(ZipList(a), Nil)\n Create a new ZipList from a list, setting the current element to the first element that satisfies the predicate///\n ## Examples\n \n from_list_by([1, 2, 3, 4, 5], fn(x) { x == 3 }) == Ok(new([1, 2], 3, [4, 5]))\n from_list_by([1, 2, 3, 4, 5], fn(x) { x == 6 }) == Error(Nil)\n \nSynonyms:\nzip_list.from_list_by\nzip_list from_list_by","url":"zip_list.html#from_list_by"},{"doc":"zip_list","title":"get_all_next","content":"pub fn get_all_next(zip_list: ZipList(a)) -&gt; List(a)\n Get the next elements of the ZipList\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; get_all_next\n // =&gt; [4, 5]\n \nSynonyms:\nzip_list.get_all_next\nzip_list get_all_next","url":"zip_list.html#get_all_next"},{"doc":"zip_list","title":"get_all_previous","content":"pub fn get_all_previous(zip_list: ZipList(a)) -&gt; List(a)\n Get the previous elements of the ZipList\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; get_all_previous\n // =&gt; [1, 2]\n \nSynonyms:\nzip_list.get_all_previous\nzip_list get_all_previous","url":"zip_list.html#get_all_previous"},{"doc":"zip_list","title":"get_next","content":"pub fn get_next(zip_list: ZipList(a)) -&gt; Result(a, Nil)\n Get the next element of the ZipList\n Returns `Error(Nil)` if there is no next element\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; get_next\n // =&gt; Ok(4)\n \n \n new([1, 2, 3], 4, [])\n |&gt; get_next\n // =&gt; Error(Nil)\n \nSynonyms:\nzip_list.get_next\nzip_list get_next","url":"zip_list.html#get_next"},{"doc":"zip_list","title":"get_previous","content":"pub fn get_previous(zip_list: ZipList(a)) -&gt; Result(a, Nil)\n Get the previous element of the ZipList\n Returns `Error(Nil)` if there is no previous element\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; get_previous\n // =&gt; Ok(2)\n \n \n new([], 3, [4, 5])\n |&gt; get_previous\n // =&gt; Error(Nil)\n \nSynonyms:\nzip_list.get_previous\nzip_list get_previous","url":"zip_list.html#get_previous"},{"doc":"zip_list","title":"index","content":"pub fn index(zip_list: ZipList(a)) -&gt; Int\n Get the index of the current element in the ZipList\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; index\n // =&gt; 2\n \n \n new([], 3, [4, 5])\n |&gt; index\n // =&gt; 0\n \nSynonyms:\nzip_list.index\nzip_list index","url":"zip_list.html#index"},{"doc":"zip_list","title":"index_map","content":"pub fn index_map(\n  zip_list: ZipList(a),\n  f: fn(a, Int) -&gt; b,\n) -&gt; ZipList(b)\n Map a function over the elements of the ZipList, passing the index of each element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n index_map(numbers, fn(x, i) { x * i }) == new([0, 2], 6, [12, 20])\n \nSynonyms:\nzip_list.index_map\nzip_list index_map","url":"zip_list.html#index_map"},{"doc":"zip_list","title":"is_first","content":"pub fn is_first(zip_list: ZipList(a)) -&gt; Bool\n Check if the current element is the first element of the ZipList\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; is_first\n // =&gt; False\n \n \n new([], 3, [4, 5])\n |&gt; is_first\n // =&gt; True\n \nSynonyms:\nzip_list.is_first\nzip_list is_first","url":"zip_list.html#is_first"},{"doc":"zip_list","title":"is_last","content":"pub fn is_last(zip_list: ZipList(a)) -&gt; Bool\n Check if the current element is the last element of the ZipList\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; is_last\n // =&gt; False\n \n \n new([1, 2], 3, [])\n |&gt; is_last\n // =&gt; True\n \nSynonyms:\nzip_list.is_last\nzip_list is_last","url":"zip_list.html#is_last"},{"doc":"zip_list","title":"jump","content":"pub fn jump(zip_list: ZipList(a), index: Int) -&gt; ZipList(a)\n Move the cursor to the Nth element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n jump(numbers, 1) == new([1], 2, [3, 4, 5])\n \n \n let numbers = new([1, 2], 3, [4, 5])\n jump(numbers, 5) == new([1, 2, 3, 4], 5, [])\n \nSynonyms:\nzip_list.jump\nzip_list jump","url":"zip_list.html#jump"},{"doc":"zip_list","title":"last","content":"pub fn last(zip_list: ZipList(a)) -&gt; ZipList(a)\n Move the cursor to the last element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n last(numbers) == new([1, 2, 3, 4], 5, [])\n \n \n let numbers = new([1, 2, 3, 4], 5, [])\n last(numbers) == new([1, 2, 3, 4], 5, [])\n \nSynonyms:\nzip_list.last\nzip_list last","url":"zip_list.html#last"},{"doc":"zip_list","title":"length","content":"pub fn length(zip_list: ZipList(a)) -&gt; Int\n Get the length of the ZipList\n\n ## Examples\n \n new([1, 2], 3, [4, 5])\n |&gt; length\n // =&gt; 5\n \nSynonyms:\nzip_list.length\nzip_list length","url":"zip_list.html#length"},{"doc":"zip_list","title":"map","content":"pub fn map(zip_list: ZipList(a), f: fn(a) -&gt; b) -&gt; ZipList(b)\n Map a function over the elements of the ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n map(numbers, fn(x) { x * 2 }) == new([2, 4], 6, [8, 10])\n \nSynonyms:\nzip_list.map\nzip_list map","url":"zip_list.html#map"},{"doc":"zip_list","title":"new","content":"pub fn new(\n  previous previous: List(a),\n  current current: a,\n  next next: List(a),\n) -&gt; ZipList(a)\n Create a new ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n current(numbers)\n // =&gt; 3\n \nSynonyms:\nzip_list.new\nzip_list new","url":"zip_list.html#new"},{"doc":"zip_list","title":"next","content":"pub fn next(zip_list: ZipList(a)) -&gt; ZipList(a)\n Move the cursor to the next element\n Returns the same ZipList if there is no next element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n next(numbers) == new([1, 2, 3], 4, [5])\n \n \n let numbers = new([1, 2, 3, 4, 5], 6, [])\n next(numbers) == new([1, 2, 3, 4, 5], 6, [])\n \nSynonyms:\nzip_list.next\nzip_list next","url":"zip_list.html#next"},{"doc":"zip_list","title":"next_try","content":"pub fn next_try(zip_list: ZipList(a)) -&gt; Result(ZipList(a), Nil)\n Move the cursor to the next element\n Returns `Error(Nil)` if there is no next element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n next_try(numbers) == Ok(new([1, 2, 3], 4, [5]))\n \n \n let numbers = new([1, 2, 3, 4, 5], 6, [])\n next_try(numbers) == Error(Nil)\n \nSynonyms:\nzip_list.next_try\nzip_list next_try","url":"zip_list.html#next_try"},{"doc":"zip_list","title":"next_wrap","content":"pub fn next_wrap(zip_list: ZipList(a)) -&gt; ZipList(a)\n Move the cursor to the next element, wrapping around to the first element if there is no next element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n next_wrap(numbers) == new([1, 2, 3], 4, [5])\n \n \n let numbers = new([1, 2, 3, 4, 5], 6, [])\n next_wrap(numbers) == new([], 1, [2, 3, 4, 5, 6])\n \nSynonyms:\nzip_list.next_wrap\nzip_list next_wrap","url":"zip_list.html#next_wrap"},{"doc":"zip_list","title":"prepend_next","content":"pub fn prepend_next(\n  zip_list: ZipList(a),\n  next: List(a),\n) -&gt; ZipList(a)\n Prepend a list to the next elements of the ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n prepend_next(numbers, [6, 7]) == new([1, 2], 3, [6, 7, 4, 5])\n \nSynonyms:\nzip_list.prepend_next\nzip_list prepend_next","url":"zip_list.html#prepend_next"},{"doc":"zip_list","title":"prepend_previous","content":"pub fn prepend_previous(\n  zip_list: ZipList(a),\n  previous: List(a),\n) -&gt; ZipList(a)\n Prepend a list to the previous elements of the ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n prepend_previous(numbers, [-1, 0]) == new([-1, 0, 1, 2], 3, [4, 5])\n \nSynonyms:\nzip_list.prepend_previous\nzip_list prepend_previous","url":"zip_list.html#prepend_previous"},{"doc":"zip_list","title":"previous","content":"pub fn previous(zip_list: ZipList(a)) -&gt; ZipList(a)\n Move the cursor to the previous element\n Returns the same ZipList if there is no previous element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n previous(numbers) == new([1], 2, [3, 4, 5])\n \n \n let numbers = new([], 1, [2, 3, 4, 5])\n previous(numbers) == new([], 1, [2, 3, 4, 5])\n \nSynonyms:\nzip_list.previous\nzip_list previous","url":"zip_list.html#previous"},{"doc":"zip_list","title":"previous_try","content":"pub fn previous_try(\n  zip_list: ZipList(a),\n) -&gt; Result(ZipList(a), Nil)\n Move the cursor to the previous element\n Returns `Error(Nil)` if there is no previous element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n previous_try(numbers) == Ok(new([1], 2, [3, 4, 5]))\n \n \n let numbers = new([], 1, [2, 3, 4, 5])\n previous_try(numbers) == Error(Nil)\n \nSynonyms:\nzip_list.previous_try\nzip_list previous_try","url":"zip_list.html#previous_try"},{"doc":"zip_list","title":"previous_wrap","content":"pub fn previous_wrap(zip_list: ZipList(a)) -&gt; ZipList(a)\n Move the cursor to the previous element, wrapping around to the last element if there is no previous element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n previous_wrap(numbers) == new([1, 2, 3], 4, [5])\n \n \n let numbers = new([], 1, [2, 3, 4, 5])\n previous_wrap(numbers) == new([1, 2, 3, 4], 5, [])\n \nSynonyms:\nzip_list.previous_wrap\nzip_list previous_wrap","url":"zip_list.html#previous_wrap"},{"doc":"zip_list","title":"remove","content":"pub fn remove(zip_list: ZipList(a)) -&gt; ZipList(a)\n Remove the current element from the ZipList\n The cursor is moved to the next element if there is one, otherwise to the previous element\n Returns the same ZipList if there is no next or previous element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n remove(numbers) == new([1, 2], 4, [5])\n \n \n let numbers = new([1, 2], 3, [])\n remove(numbers) == new([1], 2, [])\n \n \n let numbers = new([], 1, [])\n remove(numbers) == new([], 1, [])\n \nSynonyms:\nzip_list.remove\nzip_list remove","url":"zip_list.html#remove"},{"doc":"zip_list","title":"remove_backwards","content":"pub fn remove_backwards(zip_list: ZipList(a)) -&gt; ZipList(a)\n Remove the current element from the ZipList\n The cursor is moved to the previous element if there is one, otherwise to the next element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n remove_backwards(numbers) == new([1], 2, [3, 4, 5])\n \n \n let numbers = new([], 1, [2, 3])\n remove_backwards(numbers) == new([], 2, [3])\n \n \n let numbers = new([], 1, [])\n remove(numbers) == new([], 1, [])\n \nSynonyms:\nzip_list.remove_backwards\nzip_list remove_backwards","url":"zip_list.html#remove_backwards"},{"doc":"zip_list","title":"remove_try","content":"pub fn remove_try(\n  zip_list: ZipList(a),\n) -&gt; Result(ZipList(a), Nil)\n Remove the current element from the ZipList\n The cursor is moved to the next element if there is one, otherwise to the previous element\n Returns `Error(Nil)` if there is no next or previous element\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n remove_try(numbers) == Ok(new([1, 2], 4, [5]))\n \n \n let numbers = new([1, 2], 3, [])\n remove_try(numbers) == Ok(new([1], 2, []))\n \n \n let numbers = new([], 1, [])\n remove_try(numbers) == Error(Nil)\n \nSynonyms:\nzip_list.remove_try\nzip_list remove_try","url":"zip_list.html#remove_try"},{"doc":"zip_list","title":"replace","content":"pub fn replace(\n  zip_list: ZipList(a),\n  new_current: a,\n) -&gt; ZipList(a)\n Replace the current element of the ZipList\n\n ## Examples\n \n let numbers = new([1, 2], 3, [4, 5])\n replace(numbers, 6) == new([1, 2], 6, [4, 5])\n \nSynonyms:\nzip_list.replace\nzip_list replace","url":"zip_list.html#replace"},{"doc":"zip_list","title":"singleton","content":"pub fn singleton(current: a) -&gt; ZipList(a)\n Create a new ZipList with a single element\n\n ## Examples\n \n singleton(1) == new([], 1, [])\n \nSynonyms:\nzip_list.singleton\nzip_list singleton","url":"zip_list.html#singleton"},{"doc":"zip_list","title":"to_list","content":"pub fn to_list(zip_list: ZipList(a)) -&gt; List(a)\n Convert a ZipList to a list\n\n ## Examples\n \n to_list(new([1, 2], 3, [4, 5]))\n // =&gt; [1, 2, 3, 4, 5]\n \nSynonyms:\nzip_list.to_list\nzip_list to_list","url":"zip_list.html#to_list"},{"doc":"zip_list","title":"zip_list","content":"","url":"zip_list.html"}]);